Module: Vector2d::Deprecation
- Included in:
- Vector2d
- Defined in:
- lib/vector2d/deprecation.rb
Overview
The warning issued by the methods deprecated for 3.0. Each of them names its replacement, and forwards to it.
The warning issued by the methods deprecated for 3.0. Each of them names its replacement, and forwards to it.